@@ -29,7 +29,7 @@ test_that("inputs are checked when creating AuthState", {
   expect_is(a, "AuthState")
 })
 
-test_that("AuthState app can be modified", {
+test_that("AuthState app can be modified and cleared", {
   app <- httr::oauth_app("AAA", key = "KEY", secret = "SECRET")
   a <- init_AuthState(app = app, api_key = "API_KEY", auth_active = TRUE)
   expect_identical(a$app$appname, "AAA")
@@ -37,15 +37,21 @@ test_that("AuthState app can be modified", {
   app2 <- httr::oauth_app("BBB", key = "KEY", secret = "SECRET")
   a$set_app(app2)
   expect_identical(a$app$appname, "BBB")
+
+  a$set_app(NULL)
+  expect_null(a$app)
 })
 
-test_that("AuthState api_key can be modified", {
+test_that("AuthState api_key can be modified and cleared", {
   app <- httr::oauth_app("AAA", key = "KEY", secret = "SECRET")
   a <- init_AuthState(app = app, api_key = "AAA", auth_active = TRUE)
   expect_identical(a$api_key, "AAA")
 
   a$set_api_key("BBB")
   expect_identical(a$api_key, "BBB")
+
+  a$set_api_key(NULL)
+  expect_null(a$api_key)
 })
 
 test_that("AuthState auth_active can be toggled", {
